@@ -2,7 +2,7 @@
  * aout_dummy.c : dummy audio output plugin
  *****************************************************************************
  * Copyright (C) 2000, 2001 VideoLAN
- * $Id: aout_dummy.c,v 1.10 2001/03/21 13:42:33 sam Exp $
+ * $Id: aout_dummy.c,v 1.14 2001/07/12 20:44:52 reno Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *
@@ -40,6 +40,7 @@
 #include "main.h"
 
 #include "modules.h"
+#include "modules_export.h"
 
 /*****************************************************************************
  * vout_dummy_t: dummy video output method descriptor
@@ -49,6 +50,8 @@
  *****************************************************************************/
 typedef struct aout_sys_s
 {
+    /* Prevent malloc(0) */
+    int i_dummy;
 
 } aout_sys_t;
 
@@ -111,6 +114,8 @@ static int aout_Open( aout_thread_t *p_aout )
  *****************************************************************************/
 static int aout_SetFormat( aout_thread_t *p_aout )
 {
+    p_aout->i_latency = 0;
+
     return( 0 );
 }
 
